.. _utilipy-ipython:

***************************
IPython (`utilipy.ipython`)
***************************

.. currentmodule:: utilipy.ipython


Submodules
==========

.. toctree::
   :maxdepth: 1

   autoreload
   imports
   notebook
   plot
   printing


Reference/API
=============

.. automodapi:: utilipy.ipython
	:include-all-objects:
	:skip:get_ipython
    :skip:InteractiveShell
    :skip:set_trace
    :skip:display
    :skip:Latex
    :skip:Markdown
    :skip:HTML
